@@ -237,6 +237,58 @@ void AgentBase::ObserverV3::itemsUnlinked(const Akonadi::Item::List& items, cons
   }
 }
 
+void AgentBase::ObserverV4::tagAdded( const Tag &tag )
+{
+  Q_UNUSED( tag );
+
+  if ( sAgentBase != 0 ) {
+    // not implementation, let's disconnect the signal to enable optimization in Monitor
+    QObject::disconnect( sAgentBase->changeRecorder(), SIGNAL(tagAdded(Akonadi::Tag)),
+                         sAgentBase->d_ptr, SLOT(tagAdded(Akonadi::Tag)) );
+    sAgentBase->d_ptr->changeProcessed();
+  }
+}
+
+void AgentBase::ObserverV4::tagChanged( const Tag &tag )
+{
+  Q_UNUSED( tag );
+
+  if ( sAgentBase != 0 ) {
+    // not implementation, let's disconnect the signal to enable optimization in Monitor
+    QObject::disconnect( sAgentBase->changeRecorder(), SIGNAL(tagChanged(Akonadi::Tag)),
+                         sAgentBase->d_ptr, SLOT(tagChanged(Akonadi::Tag)) );
+    sAgentBase->d_ptr->changeProcessed();
+  }
+}
+
+void AgentBase::ObserverV4::tagRemoved( const Tag &tag )
+{
+  Q_UNUSED( tag );
+
+  if ( sAgentBase != 0 ) {
+    // not implementation, let's disconnect the signal to enable optimization in Monitor
+    QObject::disconnect( sAgentBase->changeRecorder(), SIGNAL(tagRemoved(Akonadi::Tag)),
+                         sAgentBase->d_ptr, SLOT(tagRemoved(Akonadi::Tag)) );
+    sAgentBase->d_ptr->changeProcessed();
+  }
+}
+
+void AgentBase::ObserverV4::itemsTagsChanged( const Item::List &items, const QSet<Tag> &addedTags, const QSet<Tag> &removedTags )
+{
+  Q_UNUSED( items );
+  Q_UNUSED( addedTags );
+  Q_UNUSED( removedTags );
+
+  if ( sAgentBase != 0 ) {
+    // not implementation, let's disconnect the signal to enable optimization in Monitor
+    QObject::disconnect( sAgentBase->changeRecorder(), SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)),
+                         sAgentBase->d_ptr, SLOT(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)) );
+    sAgentBase->d_ptr->changeProcessed();
+  }
+}
+
+
+
 //@cond PRIVATE
 
 AgentBasePrivate::AgentBasePrivate( AgentBase *parent )
@@ -250,11 +302,9 @@ AgentBasePrivate::AgentBasePrivate( AgentBase *parent )
     mSettings( 0 ),
     mChangeRecorder( 0 ),
     mTracer( 0 ),
-    mObserver( 0 )
+    mObserver(0),
+    mTemporaryOfflineTimer(0)
 {
-#ifdef Q_OS_WINCE
-  QThread::currentThread()->setPriority( QThread::LowPriority );
-#endif
   Internal::setClientType( Internal::Agent );
 }
 
@@ -342,12 +392,10 @@ void AgentBasePrivate::init()
     KGlobal::setAllowQuit( true );
   }
 
-#ifndef Q_OS_WINCE
   // disable session management
   if ( KApplication::kApplication() ) {
     KApplication::kApplication()->disableSessionManagement();
   }
-#endif
 
   mResourceTypeName = AgentManager::self()->instance( mId ).type().name();
   setProgramName();
@@ -513,6 +561,62 @@ void AgentBasePrivate::itemsUnlinked( const Akonadi::Item::List &items, const Ak
   }
 }
 
+void AgentBasePrivate::tagAdded( const Akonadi::Tag &tag )
+{
+  if ( !mObserver ) {
+    return;
+  }
+
+  AgentBase::ObserverV4 *observer4 = dynamic_cast<AgentBase::ObserverV4*>( mObserver );
+  if ( observer4 ) {
+    observer4->tagAdded( tag );
+  } else {
+    changeProcessed();
+  }
+}
+
+void AgentBasePrivate::tagChanged( const Akonadi::Tag &tag )
+{
+  if ( !mObserver ) {
+    return;
+  }
+
+  AgentBase::ObserverV4 *observer4 = dynamic_cast<AgentBase::ObserverV4*>( mObserver );
+  if ( observer4 ) {
+    observer4->tagChanged( tag );
+  } else {
+    changeProcessed();
+  }
+}
+
+void AgentBasePrivate::tagRemoved( const Akonadi::Tag &tag )
+{
+  if ( !mObserver ) {
+    return;
+  }
+
+  AgentBase::ObserverV4 *observer4 = dynamic_cast<AgentBase::ObserverV4*>( mObserver );
+  if ( observer4 ) {
+    observer4->tagRemoved( tag );;
+  } else {
+    changeProcessed();
+  }
+}
+
+void AgentBasePrivate::itemsTagsChanged( const Akonadi::Item::List &items, const QSet<Akonadi::Tag> &addedTags, const QSet<Akonadi::Tag> &removedTags )
+{
+  if ( !mObserver ) {
+    return;
+  }
+
+  AgentBase::ObserverV4 *observer4 = dynamic_cast<AgentBase::ObserverV4*>( mObserver );
+  if ( observer4 ) {
+    observer4->itemsTagsChanged( items, addedTags, removedTags );
+  } else {
+    changeProcessed();
+  }
+}
+
 void AgentBasePrivate::collectionAdded( const Akonadi::Collection &collection, const Akonadi::Collection &parent )
 {
   if ( mObserver != 0 ) {
@@ -636,8 +740,9 @@ void AgentBasePrivate::slotError( const QString& message )
 
 void AgentBasePrivate::slotNetworkStatusChange( Solid::Networking::Status stat )
 {
+  Q_UNUSED( stat );
   Q_Q( AgentBase );
-  q->setOnlineInternal( mDesiredOnlineState && ( stat == Solid::Networking::Unknown || stat == Solid::Networking::Connected ) );
+  q->setOnlineInternal( mDesiredOnlineState );
 }
 
 void AgentBasePrivate::slotResumedFromSuspend()
@@ -647,6 +752,12 @@ void AgentBasePrivate::slotResumedFromSuspend()
   }
 }
 
+void AgentBasePrivate::slotTemporaryOfflineTimeout()
+{
+  Q_Q(AgentBase);
+  q->setOnlineInternal(true);
+}
+
 QString AgentBasePrivate::dumpNotificationListToString() const
 {
   return mChangeRecorder->dumpNotificationListToString();
@@ -812,11 +923,42 @@ void AgentBase::setOnline( bool state )
   setOnlineInternal( state );
 }
 
+void AgentBase::setTemporaryOffline(int makeOnlineInSeconds)
+{
+  Q_D(AgentBase);
+
+  // if not currently online, avoid bringing it online after the timeout
+  if (!d->mOnline) {
+      return;
+  }
+
+  setOnlineInternal(false);
+
+  if (!d->mTemporaryOfflineTimer) {
+      d->mTemporaryOfflineTimer = new QTimer(d);
+      d->mTemporaryOfflineTimer->setSingleShot(true);
+      connect(d->mTemporaryOfflineTimer, SIGNAL(timeout()), this, SLOT(slotTemporaryOfflineTimeout()));
+  }
+  d->mTemporaryOfflineTimer->setInterval(makeOnlineInSeconds * 1000);
+  d->mTemporaryOfflineTimer->start();
+}
+
 void AgentBase::setOnlineInternal( bool state )
 {
   Q_D( AgentBase );
+  if (state && d->mNeedsNetwork) {
+    const Solid::Networking::Status stat = Solid::Networking::status();
+    if (stat != Solid::Networking::Unknown && stat != Solid::Networking::Connected) {
+      //Don't go online if the resource needs network but there is none
+      state = false;
+    }
+  }
   d->mOnline = state;
 
+  if (d->mTemporaryOfflineTimer) {
+      d->mTemporaryOfflineTimer->stop();
+  }
+
   const QString newMessage = d->defaultReadyMessage();
   if ( d->mStatusMessage != newMessage && d->mStatusCode != AgentBase::Broken ) {
     emit status( d->mStatusCode, newMessage );
@@ -923,8 +1065,17 @@ void AgentBase::registerObserver( Observer *observer )
   // TODO in theory we should re-connect change recorder signals here that we disconnected previously
   d_ptr->mObserver = observer;
 
-  const bool haveObserverV3 = (dynamic_cast<AgentBase::ObserverV3*>(d_ptr->mObserver) != 0);
+  const bool hasObserverV3 = (dynamic_cast<AgentBase::ObserverV3*>(d_ptr->mObserver) != 0);
+  const bool hasObserverV4 = (dynamic_cast<AgentBase::ObserverV4*>(d_ptr->mObserver) != 0);
 
+  disconnect( d_ptr->mChangeRecorder, SIGNAL(tagAdded(Akonadi::Tag)),
+              d_ptr, SLOT(tagAdded(Akonadi::Tag)) );
+  disconnect( d_ptr->mChangeRecorder, SIGNAL(tagChanged(Akonadi::Tag)),
+              d_ptr, SLOT(tagChanged(Akonadi::Tag)) );
+  disconnect( d_ptr->mChangeRecorder, SIGNAL(tagRemoved(Akonadi::Tag)),
+              d_ptr, SLOT(tagRemoved(Akonadi::Tag)) );
+  disconnect( d_ptr->mChangeRecorder, SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)),
+              d_ptr, SLOT(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)) );
   disconnect( d_ptr->mChangeRecorder, SIGNAL(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)),
               d_ptr, SLOT(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)) );
   disconnect( d_ptr->mChangeRecorder, SIGNAL(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)),
@@ -944,7 +1095,18 @@ void AgentBase::registerObserver( Observer *observer )
   disconnect( d_ptr->mChangeRecorder, SIGNAL(itemUnlinked(Akonadi::Item,Akonadi::Collection)),
               d_ptr, SLOT(itemUnlinked(Akonadi::Item,Akonadi::Collection)) );
 
-  if ( haveObserverV3 ) {
+  if ( hasObserverV4 ) {
+    connect( d_ptr->mChangeRecorder, SIGNAL(tagAdded(Akonadi::Tag)),
+             d_ptr, SLOT(tagAdded(Akonadi::Tag)) );
+    connect( d_ptr->mChangeRecorder, SIGNAL(tagChanged(Akonadi::Tag)),
+             d_ptr, SLOT(tagChanged(Akonadi::Tag)) );
+    connect( d_ptr->mChangeRecorder, SIGNAL(tagRemoved(Akonadi::Tag)),
+             d_ptr, SLOT(tagRemoved(Akonadi::Tag)) );
+    connect( d_ptr->mChangeRecorder, SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)),
+             d_ptr, SLOT(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)) );
+  }
+
+  if ( hasObserverV3 ) {
     connect( d_ptr->mChangeRecorder, SIGNAL(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)),
              d_ptr, SLOT(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)) );
     connect( d_ptr->mChangeRecorder, SIGNAL(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)),
@@ -956,6 +1118,7 @@ void AgentBase::registerObserver( Observer *observer )
     connect( d_ptr->mChangeRecorder, SIGNAL(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)),
              d_ptr, SLOT(itemsUnlinked(Akonadi::Item::List,Akonadi::Collection)) );
   } else {
+    // V2 - don't connect these if we have V3
     connect( d_ptr->mChangeRecorder, SIGNAL(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)),
              d_ptr, SLOT(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)) );
     connect( d_ptr->mChangeRecorder, SIGNAL(itemRemoved(Akonadi::Item)),
