@@ -29,6 +29,7 @@
 #include <solid/networking.h>
 
 class QSettings;
+class QTimer;
 
 namespace Akonadi {
 
@@ -52,6 +53,7 @@ class AgentBasePrivate : public QObject
     void slotError( const QString& message );
     void slotNetworkStatusChange( Solid::Networking::Status );
     void slotResumedFromSuspend();
+    void slotTemporaryOfflineTimeout();
 
     virtual void changeProcessed();
 
@@ -108,6 +110,8 @@ class AgentBasePrivate : public QObject
 
     AgentBase::Observer *mObserver;
 
+    QTimer *mTemporaryOfflineTimer;
+
   public Q_SLOTS:
     // Dump the contents of the current ChangeReplay
     Q_SCRIPTABLE QString dumpNotificationListToString() const;
@@ -134,6 +138,11 @@ class AgentBasePrivate : public QObject
     virtual void collectionRemoved( const Akonadi::Collection &collection );
     void collectionSubscribed( const Akonadi::Collection &collection, const Akonadi::Collection &parent );
     void collectionUnsubscribed( const Akonadi::Collection &collection );
+
+    virtual void tagAdded( const Akonadi::Tag &tag );
+    virtual void tagChanged( const Akonadi::Tag &tag );
+    virtual void tagRemoved( const Akonadi::Tag &tag );
+    virtual void itemsTagsChanged( const Akonadi::Item::List &items, const QSet<Akonadi::Tag> &addedTags, const QSet<Akonadi::Tag> &removedTags );
 };
 
 }
