@@ -21,7 +21,6 @@
 #include "changemediator_p.h"
 
 #include <QApplication>
-#include <QTimer>
 
 #include "changenotificationdependenciesfactory_p.h"
 #include "notificationsourceinterface.h"
@@ -80,6 +79,12 @@ void ChangeMediator::invalidateItem(const Akonadi::Item& item)
   QMetaObject::invokeMethod( instance(), "do_invalidateItem", Q_ARG( Akonadi::Item, item ) );
 }
 
+/* static */
+void ChangeMediator::invalidateTag( const Tag &tag )
+{
+  QMetaObject::invokeMethod( instance(), "do_invalidateTag", Q_ARG( Akonadi::Tag, tag ) );
+}
+
 void ChangeMediator::do_registerMonitor( QObject *monitor )
 {
   m_monitors.append( monitor );
@@ -104,6 +109,14 @@ void ChangeMediator::do_invalidateItem( const Akonadi::Item &item )
   }
 }
 
+void ChangeMediator::do_invalidateTag( const Tag &tag )
+{
+  foreach ( QObject *monitor, m_monitors ) {
+    QMetaObject::invokeMethod( monitor, "invalidateTagCache", Qt::AutoConnection, Q_ARG( qint64, tag.id() ) );
+  }
+}
+
+
 /* static */
 void ChangeMediator::registerSession( const QByteArray &id )
 {
