@@ -136,6 +136,8 @@ class AKONADI_EXPORT CollectionRequester : public KHBox
     Private * const d;
 
     Q_PRIVATE_SLOT( d, void _k_slotOpenDialog() )
+    Q_PRIVATE_SLOT( d, void _k_collectionReceived( KJob *job ) )
+    Q_PRIVATE_SLOT( d, void _k_collectionsNamesReceived( KJob *job ) );
 };
 
 } // namespace Akonadi
