@@ -643,7 +643,7 @@ class CollectionSync::Private
     void execute()
     {
       kDebug() << Q_FUNC_INFO << "localListDone: " << localListDone << " deliveryDone: " << deliveryDone;
-      if ( !localListDone ) {
+      if ( !localListDone || !deliveryDone ) {
         return;
       }
 
