@@ -23,9 +23,10 @@
 #include "collectionmodel.h"
 #include "control.h"
 
+#include <kicon.h>
 #include <kaction.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <kurl.h>
 #include <kxmlguifactory.h>
