@@ -37,13 +37,13 @@ Q_OBJECT
 public:
     explicit TextBrowser( QWidget *parent = 0 );
 private Q_SLOTS:
-    void slotCopyEmail();
+    void slotCopyData();
 protected:
 #ifndef QT_NO_CONTEXTMENU
     virtual void contextMenuEvent( QContextMenuEvent *event );
 #endif
 private:
-    QString mLinkToCopy;
+    QVariant mDataToCopy;
 };
 
 }
