@@ -26,6 +26,9 @@
 #include <akonadi/collection.h>
 #include <akonadi/collectionfetchjob.h>
 #include <akonadi/collectionfetchscope.h>
+#include <akonadi/tag.h>
+#include <akonadi/tagfetchjob.h>
+#include <akonadi/tagfetchscope.h>
 #include <akonadi/session.h>
 
 #include "akonadiprivate_export.h"
@@ -36,6 +39,7 @@
 #include <QHash>
 #include <QtCore/QQueue>
 
+class Dummy;
 class KJob;
 
 typedef QList<Akonadi::Entity::Id> EntityIdList;
@@ -58,10 +62,10 @@ class AKONADI_TESTS_EXPORT EntityCacheBase : public QObject
   protected:
     Session *session;
 
-  signals:
+  Q_SIGNALS:
     void dataAvailable();
 
-  private slots:
+  private Q_SLOTS:
     virtual void processResult( KJob* job ) = 0;
 };
 
@@ -160,8 +164,7 @@ class EntityCache : public EntityCacheBase
       Q_ASSERT( !isRequested( id ) );
       shrinkCache();
       EntityCacheNode<T> *node = new EntityCacheNode<T>( id );
-      FetchJob* job = createFetchJob( id );
-      job->setFetchScope( scope );
+      FetchJob* job = createFetchJob( id, scope );
       job->setProperty( "EntityCacheNode", QVariant::fromValue<typename T::Id>( id ) );
       connect( job, SIGNAL( result( KJob* )), SLOT(processResult( KJob* ) ) );
       mCache.enqueue( node );
@@ -202,9 +205,11 @@ class EntityCache : public EntityCacheBase
 
     void extractResult( EntityCacheNode<T>* node, KJob* job ) const;
 
-    inline FetchJob* createFetchJob( typename T::Id id )
+    inline FetchJob* createFetchJob( typename T::Id id, const FetchScope &scope )
     {
-      return new FetchJob( T( id ), session );
+      FetchJob *fetch = new FetchJob( T( id ), session );
+      fetch->setFetchScope( scope );
+      return fetch;
     }
 
     /** Tries to reduce the cache size until at least one more object fits in. */
@@ -242,13 +247,29 @@ template<> inline void EntityCache<Item, ItemFetchJob, ItemFetchScope>::extractR
   }
 }
 
-template<> inline CollectionFetchJob* EntityCache<Collection, CollectionFetchJob, CollectionFetchScope>::createFetchJob( Collection::Id id )
+template<> inline void EntityCache<Tag, TagFetchJob, TagFetchScope>::extractResult( EntityCacheNode<Tag>* node, KJob* job) const
 {
-  return new CollectionFetchJob( Collection( id ), CollectionFetchJob::Base, session );
+  TagFetchJob *fetch = qobject_cast<TagFetchJob*>( job );
+  Q_ASSERT( fetch );
+  if ( fetch->tags().isEmpty() ) {
+    node->entity = Tag();
+  } else {
+    node->entity = fetch->tags().first();
+  }
 }
 
+
+template<> inline CollectionFetchJob* EntityCache<Collection, CollectionFetchJob, CollectionFetchScope>::createFetchJob( Collection::Id id, const CollectionFetchScope &scope )
+{
+  CollectionFetchJob *fetch = new CollectionFetchJob( Collection( id ), CollectionFetchJob::Base, session );
+  fetch->setFetchScope( scope );
+  return fetch;
+}
+
+
 typedef EntityCache<Collection, CollectionFetchJob, CollectionFetchScope> CollectionCache;
 typedef EntityCache<Item, ItemFetchJob, ItemFetchScope> ItemCache;
+typedef EntityCache<Tag, TagFetchJob, TagFetchScope> TagCache;
 
 template <typename T>
 struct EntityListCacheNode
@@ -363,8 +384,7 @@ public:
       EntityListCacheNode<T> *node = new EntityListCacheNode<T>( id );
       mCache.insert( id, node );
     }
-    FetchJob* job = createFetchJob( ids );
-    job->setFetchScope( scope );
+    FetchJob* job = createFetchJob( ids, scope );
     job->setProperty( "EntityListCacheIds", QVariant::fromValue< QList<Entity::Id> >( ids ) );
     connect( job, SIGNAL(result(KJob*)), SLOT(processResult(KJob*)) );
   }
@@ -408,9 +428,11 @@ private:
     }
   }
 
-  inline FetchJob* createFetchJob( const QList<Entity::Id> &ids )
+  inline FetchJob* createFetchJob( const QList<Entity::Id> &ids, const FetchScope &scope )
   {
-    return new FetchJob( ids, session );
+    FetchJob *job = new FetchJob( ids, session );
+    job->setFetchScope( scope );
+    return job;
   }
 
   void processResult( KJob* job )
@@ -472,14 +494,24 @@ template<> inline void EntityListCache<Item, ItemFetchJob, ItemFetchScope>::extr
   items = fetch->items();
 }
 
-template<>
-inline CollectionFetchJob* EntityListCache<Collection, CollectionFetchJob, CollectionFetchScope>::createFetchJob( const QList<Entity::Id> &ids )
+template<> inline void EntityListCache<Tag, TagFetchJob, TagFetchScope>::extractResults( KJob *job, Tag::List &tags )  const
 {
-  return new CollectionFetchJob( ids, CollectionFetchJob::Base, session );
+  TagFetchJob* fetch = qobject_cast<TagFetchJob*>( job );
+  Q_ASSERT( fetch );
+  tags = fetch->tags();
+}
+
+template<>
+inline CollectionFetchJob* EntityListCache<Collection, CollectionFetchJob, CollectionFetchScope>::createFetchJob( const QList<Entity::Id> &ids, const CollectionFetchScope &scope )
+{
+  CollectionFetchJob *fetch = new CollectionFetchJob( ids, CollectionFetchJob::Base, session );
+  fetch->setFetchScope( scope );
+  return fetch;
 }
 
 typedef EntityListCache<Collection, CollectionFetchJob, CollectionFetchScope> CollectionListCache;
 typedef EntityListCache<Item, ItemFetchJob, ItemFetchScope> ItemListCache;
+typedef EntityListCache<Tag, TagFetchJob, TagFetchScope> TagListCache;
 
 }
 
