@@ -95,7 +95,7 @@ void ItemFetchScope::fetchAllAttributes(bool fetch)
 
 bool ItemFetchScope::isEmpty() const
 {
-  return d->mPayloadParts.isEmpty() && d->mAttributes.isEmpty() && !d->mFullPayload && !d->mAllAttributes;
+  return d->mPayloadParts.isEmpty() && d->mAttributes.isEmpty() && !d->mFullPayload && !d->mAllAttributes && !d->mFetchTags;
 }
 
 bool ItemFetchScope::cacheOnly() const
@@ -179,3 +179,13 @@ bool ItemFetchScope::fetchRemoteIdentification() const
 {
   return d->mFetchRid;
 }
+
+void ItemFetchScope::setFetchTags( bool fetchTags )
+{
+  d->mFetchTags = fetchTags;
+}
+
+bool ItemFetchScope::fetchTags() const
+{
+  return d->mFetchTags;
+}
