@@ -28,10 +28,10 @@
 #include "notificationmessagev2_p.h"
 #include "notificationmanagerinterface.h"
 #include "session.h"
+#include "changemediator_p.h"
 
 #include <kdebug.h>
 #include <kcomponentdata.h>
-#include "changemediator_p.h"
 
 using namespace Akonadi;
 
@@ -46,12 +46,12 @@ MonitorPrivate::MonitorPrivate( ChangeNotificationDependenciesFactory *dependenc
   session( Session::defaultSession() ),
   collectionCache( 0 ),
   itemCache( 0 ),
+  tagCache(0),
   fetchCollection( false ),
   fetchCollectionStatistics( false ),
   collectionMoveTranslationEnabled( true ),
   useRefCounting( false )
 {
-
 }
 
 void MonitorPrivate::init()
@@ -61,12 +61,17 @@ void MonitorPrivate::init()
   // needs to be at least 1x pipeline size
   itemCache = dependenciesFactory->createItemListCache(PipelineSize, session);
 
+  // 20 tags looks like a reasonable mount to keep around
+  tagCache = dependenciesFactory->createTagListCache(20, session);
+
   QObject::connect( collectionCache, SIGNAL(dataAvailable()), q_ptr, SLOT(dataAvailable()) );
   QObject::connect( itemCache, SIGNAL(dataAvailable()), q_ptr, SLOT(dataAvailable()) );
+  QObject::connect( tagCache, SIGNAL(dataAvailable()), q_ptr, SLOT(dataAvailable()) );
   QObject::connect( ServerManager::self(), SIGNAL(stateChanged(Akonadi::ServerManager::State)),
                     q_ptr, SLOT(serverStateChanged(Akonadi::ServerManager::State)) );
 
   NotificationMessageV2::registerDBusTypes();
+  NotificationMessageV3::registerDBusTypes();
 
   statisticsCompressionTimer.setSingleShot( true );
   statisticsCompressionTimer.setInterval( 500 );
@@ -83,8 +88,8 @@ bool MonitorPrivate::connectToNotificationManager()
   if (!notificationSource)
     return false;
 
-  QObject::connect( notificationSource, SIGNAL(notifyV2(Akonadi::NotificationMessageV2::List)),
-                    q_ptr, SLOT(slotNotify(Akonadi::NotificationMessageV2::List)) );
+  QObject::connect( notificationSource, SIGNAL(notifyV3(Akonadi::NotificationMessageV3::List)),
+                    q_ptr, SLOT(slotNotify(Akonadi::NotificationMessageV3::List)) );
 
   return true;
 }
@@ -109,6 +114,12 @@ void MonitorPrivate::serverStateChanged(ServerManager::State state)
     Q_FOREACH ( const QString &mimeType, mimetypes ) {
       notificationSource->setMonitoredMimeType( mimeType, true );
     }
+    Q_FOREACH ( Tag::Id tagId, tags ) {
+      notificationSource->setMonitoredTag( tagId, true );
+    }
+    Q_FOREACH ( Monitor::Type type, types ) {
+      notificationSource->setMonitoredType( static_cast<NotificationMessageV2::Type>( type ), true );
+    }
   }
 }
 
@@ -122,15 +133,28 @@ void MonitorPrivate::invalidateItemCache( qint64 id )
   itemCache->update( QList<Entity::Id>() << id, mItemFetchScope );
 }
 
+void MonitorPrivate::invalidateTagCache( qint64 id )
+{
+  tagCache->update( QList<Tag::Id>() << id, mTagFetchScope );
+}
+
 int MonitorPrivate::pipelineSize() const
 {
   return PipelineSize;
 }
 
-bool MonitorPrivate::isLazilyIgnored( const NotificationMessageV2 & msg, bool allowModifyFlagsConversion ) const
+bool MonitorPrivate::isLazilyIgnored( const NotificationMessageV3 &msg, bool allowModifyFlagsConversion ) const
 {
   NotificationMessageV2::Operation op = msg.operation();
 
+  if ( msg.type() == NotificationMessageV2::Tags
+    && ( ( op == NotificationMessageV2::Add && q_ptr->receivers( SIGNAL(tagAdded(Akonadi::Tag)) ) == 0 )
+      || ( op == NotificationMessageV2::Modify && q_ptr->receivers( SIGNAL(tagChanged(Akonadi::Tag)) ) == 0 )
+      || ( op == NotificationMessageV2::Remove && q_ptr->receivers( SIGNAL(tagRemoved(Akonadi::Tag)) ) == 0 ) ) )
+  {
+    return true;
+  }
+
   if ( !fetchCollectionStatistics &&
        ( msg.type() == NotificationMessageV2::Items ) && ( ( op == NotificationMessageV2::Add && q_ptr->receivers( SIGNAL(itemAdded(Akonadi::Item,Akonadi::Collection)) ) == 0 )
     || ( op == NotificationMessageV2::Remove && q_ptr->receivers( SIGNAL(itemRemoved(Akonadi::Item)) ) == 0
@@ -143,6 +167,7 @@ bool MonitorPrivate::isLazilyIgnored( const NotificationMessageV2 & msg, bool al
           && ( !allowModifyFlagsConversion || q_ptr->receivers( SIGNAL(itemChanged(Akonadi::Item,QSet<QByteArray>)) ) == 0 )
           )
        )
+    || ( op == NotificationMessageV2::ModifyTags && q_ptr->receivers( SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)) ) == 0 )
     || ( op == NotificationMessageV2::Move && q_ptr->receivers( SIGNAL(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)) ) == 0
                                            && q_ptr->receivers( SIGNAL(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)) ) == 0 )
     || ( op == NotificationMessageV2::Link && q_ptr->receivers( SIGNAL(itemLinked(Akonadi::Item,Akonadi::Collection)) ) == 0
@@ -166,6 +191,7 @@ bool MonitorPrivate::isLazilyIgnored( const NotificationMessageV2 & msg, bool al
     || ( op == NotificationMessageV2::Remove )
     || ( op == NotificationMessageV2::Modify )
     || ( op == NotificationMessageV2::ModifyFlags )
+    || ( op == NotificationMessageV2::ModifyTags )
     || ( op == NotificationMessageV2::Link )
     || ( op == NotificationMessageV2::Unlink ) )
   {
@@ -185,7 +211,7 @@ bool MonitorPrivate::isLazilyIgnored( const NotificationMessageV2 & msg, bool al
   return true;
 }
 
-void MonitorPrivate::checkBatchSupport(const NotificationMessageV2& msg, bool &needsSplit, bool &batchSupported) const
+void MonitorPrivate::checkBatchSupport(const NotificationMessageV3 &msg, bool& needsSplit, bool& batchSupported) const
 {
   const bool isBatch = (msg.entities().count() > 1);
 
@@ -203,6 +229,11 @@ void MonitorPrivate::checkBatchSupport(const NotificationMessageV2& msg, bool &n
         batchSupported = q_ptr->receivers( SIGNAL(itemsFlagsChanged(Akonadi::Item::List,QSet<QByteArray>,QSet<QByteArray>)) ) > 0;
         needsSplit = isBatch && !batchSupported && q_ptr->receivers( SIGNAL(itemChanged(Akonadi::Item,QSet<QByteArray>)) ) > 0;
         return;
+      case NotificationMessageV2::ModifyTags:
+        // Tags were added after batch notifications, so they are always supported
+        batchSupported = true;
+        needsSplit = false;
+        return;
       case NotificationMessageV2::Move:
         needsSplit = isBatch && q_ptr->receivers( SIGNAL(itemMoved(Akonadi::Item,Akonadi::Collection,Akonadi::Collection)) ) > 0;
         batchSupported = q_ptr->receivers( SIGNAL(itemsMoved(Akonadi::Item::List,Akonadi::Collection,Akonadi::Collection)) ) > 0;
@@ -228,14 +259,17 @@ void MonitorPrivate::checkBatchSupport(const NotificationMessageV2& msg, bool &n
   } else if ( msg.type() == NotificationMessageV2::Collections ) {
     needsSplit = isBatch;
     batchSupported = false;
+  } else if ( msg.type() == NotificationMessageV2::Tags ) {
+    needsSplit = isBatch;
+    batchSupported = false;
   }
 }
 
-NotificationMessageV2::List MonitorPrivate::splitMessage(const NotificationMessageV2& msg, bool legacy) const
+NotificationMessageV3::List MonitorPrivate::splitMessage(const NotificationMessageV3 &msg, bool legacy) const
 {
-  NotificationMessageV2::List list;
+  NotificationMessageV3::List list;
 
-  NotificationMessageV2 baseMsg;
+  NotificationMessageV3 baseMsg;
   baseMsg.setSessionId( msg.sessionId() );
   baseMsg.setType( msg.type() );
   if ( legacy && msg.operation() == NotificationMessageV2::ModifyFlags ) {
@@ -251,9 +285,11 @@ NotificationMessageV2::List MonitorPrivate::splitMessage(const NotificationMessa
   baseMsg.setDestinationResource( msg.destinationResource() );
   baseMsg.setAddedFlags( msg.addedFlags() );
   baseMsg.setRemovedFlags( msg.removedFlags() );
+  baseMsg.setAddedTags( msg.addedTags() );
+  baseMsg.setRemovedTags( msg.removedTags() );
 
   Q_FOREACH( const NotificationMessageV2::Entity &entity, msg.entities() ) {
-    NotificationMessageV2 copy = baseMsg;
+    NotificationMessageV3 copy = baseMsg;
     copy.addEntity(entity.id, entity.remoteId, entity.remoteRevision, entity.mimeType);
 
     list << copy;
@@ -262,7 +298,7 @@ NotificationMessageV2::List MonitorPrivate::splitMessage(const NotificationMessa
   return list;
 }
 
-bool MonitorPrivate::acceptNotification( const NotificationMessageV2 &msg ) const
+bool MonitorPrivate::acceptNotification( const Akonadi::NotificationMessageV3 &msg ) const
 {
   // session is ignored
   if ( sessions.contains( msg.sessionId() ) )
@@ -275,6 +311,11 @@ bool MonitorPrivate::acceptNotification( const NotificationMessageV2 &msg ) cons
   if ( monitorAll && msg.type() != NotificationMessageV2::InvalidType)
     return true;
 
+  // Types are monitored, but not this one
+  if ( !types.isEmpty() && !types.contains( static_cast<Monitor::Type>( msg.type() ) ) ) {
+    return false;
+  }
+
   switch ( msg.type() ) {
     case NotificationMessageV2::InvalidType:
       kWarning() << "Received invalid change notification!";
@@ -320,6 +361,17 @@ bool MonitorPrivate::acceptNotification( const NotificationMessageV2 &msg ) cons
       }
       return isCollectionMonitored( msg.parentCollection() )
           || isCollectionMonitored( msg.parentDestCollection() );
+
+    case NotificationMessageV2::Tags:
+      if ( !tags.isEmpty() ) {
+        Q_FOREACH ( const NotificationMessageV2::Entity &entity, msg.entities() ) {
+          if ( tags.contains( entity.id ) ) {
+            return true;
+          }
+        }
+        return false;
+      }
+      return true;
   }
   Q_ASSERT( false );
   return false;
@@ -328,8 +380,8 @@ bool MonitorPrivate::acceptNotification( const NotificationMessageV2 &msg ) cons
 void MonitorPrivate::cleanOldNotifications()
 {
   bool erased = false;
-  for ( QQueue<NotificationMessageV2>::iterator it = pipeline.begin(); it != pipeline.end(); ) {
-    if ( !acceptNotification( *it ) ) {
+  for ( QQueue<NotificationMessageV3>::iterator it = pipeline.begin(); it != pipeline.end(); ) {
+    if ( !acceptNotification( *it ) || isLazilyIgnored( *it ) ) {
       it = pipeline.erase( it );
       erased = true;
     } else {
@@ -337,8 +389,8 @@ void MonitorPrivate::cleanOldNotifications()
     }
   }
 
-  for ( QQueue<NotificationMessageV2>::iterator it = pendingNotifications.begin(); it != pendingNotifications.end(); ) {
-    if ( !acceptNotification( *it ) ) {
+  for ( QQueue<NotificationMessageV3>::iterator it = pendingNotifications.begin(); it != pendingNotifications.end(); ) {
+    if ( !acceptNotification( *it ) || isLazilyIgnored( *it ) ) {
       it = pendingNotifications.erase( it );
       erased = true;
     } else {
@@ -349,8 +401,17 @@ void MonitorPrivate::cleanOldNotifications()
     notificationsErased();
 }
 
-bool MonitorPrivate::ensureDataAvailable( const NotificationMessageV2& msg )
+bool MonitorPrivate::ensureDataAvailable( const NotificationMessageV3 &msg )
 {
+  if ( msg.type() == NotificationMessageV2::Tags ) {
+    Q_FOREACH ( const NotificationMessageV2::Entity &entity, msg.entities() ) {
+      if ( !tagCache->ensureCached( QList<Tag::Id>() << entity.id, mTagFetchScope ) ) {
+        return false;
+      }
+    }
+    return true;
+  }
+
   bool allCached = true;
   if ( fetchCollection ) {
     if ( !collectionCache->ensureCached( msg.parentCollection(), mCollectionFetchScope ) )
@@ -391,43 +452,64 @@ bool MonitorPrivate::ensureDataAvailable( const NotificationMessageV2& msg )
     }
     if ( !itemCache->ensureCached( msg.uids(), scope ) ) {
         allCached = false;
+
     }
+
+    // Make sure all tags for ModifyTags operation are in cache too
+    if ( msg.operation() == NotificationMessageV2::ModifyTags ) {
+      if ( !tagCache->ensureCached( ( msg.addedTags() + msg.removedTags() ).toList(), mTagFetchScope ) ) {
+        allCached = false;
+      }
+    }
+
   } else if ( msg.type() == NotificationMessageV2::Collections && fetchCollection ) {
     Q_FOREACH ( const NotificationMessageV2::Entity &entity, msg.entities() ) {
-      if ( !collectionCache->ensureCached( entity.id, mCollectionFetchScope ) )
+      if ( !collectionCache->ensureCached( entity.id, mCollectionFetchScope ) ) {
         allCached = false;
+        break;
+      }
     }
   }
   return allCached;
 }
 
-bool MonitorPrivate::emitNotification( const NotificationMessageV2& msg )
+bool MonitorPrivate::emitNotification( const NotificationMessageV3 &msg )
 {
-  const Collection parent = collectionCache->retrieve( msg.parentCollection() );
-  Collection destParent;
-  if ( msg.operation() == NotificationMessageV2::Move )
-    destParent = collectionCache->retrieve( msg.parentDestCollection() );
-
   bool someoneWasListening = false;
-  if ( msg.type() == NotificationMessageV2::Collections ) {
-    Collection col;
-    Q_FOREACH ( const NotificationMessageV2::Entity &entity, msg.entities() ) {
-      col = collectionCache->retrieve( entity.id );
-      if ( emitCollectionNotification( msg, col, parent, destParent ) && !someoneWasListening )
-        someoneWasListening = true;
+  if ( msg.type() == NotificationMessageV2::Tags ) {
+    //In case of a Remove notification this will return a list of invalid entities (we'll deal later with them)
+    const Tag::List tags = tagCache->retrieve( msg.uids() );
+    someoneWasListening = emitTagsNotification( msg, tags );
+  } else {
+    const Collection parent = collectionCache->retrieve( msg.parentCollection() );
+    Collection destParent;
+    if ( msg.operation() == NotificationMessageV2::Move ) {
+      destParent = collectionCache->retrieve( msg.parentDestCollection() );
+    }
+
+    if ( msg.type() == NotificationMessageV2::Collections ) {
+      Collection col;
+      Q_FOREACH ( const NotificationMessageV2::Entity &entity, msg.entities() ) {
+        col = collectionCache->retrieve( entity.id );
+        if ( emitCollectionNotification( msg, col, parent, destParent ) && !someoneWasListening ) {
+          someoneWasListening = true;
+        }
+      }
+    } else if ( msg.type() == NotificationMessageV2::Items ) {
+      //In case of a Remove notification this will return a list of invalid entities (we'll deal later with them)
+      const Item::List items = itemCache->retrieve( msg.uids() );
+      someoneWasListening = emitItemsNotification( msg, items, parent, destParent );
     }
-  } else if ( msg.type() == NotificationMessageV2::Items ) {
-    Item::List items = itemCache->retrieve( msg.uids() );
-    someoneWasListening = emitItemsNotification( msg, items, parent, destParent );
   }
 
-  if ( !someoneWasListening )
+  if ( !someoneWasListening ) {
     cleanOldNotifications(); // probably someone disconnected a signal in the meantime, get rid of the no longer interesting stuff
+  }
 
   return someoneWasListening;
 }
 
-void MonitorPrivate::updatePendingStatistics( const NotificationMessageV2& msg )
+void MonitorPrivate::updatePendingStatistics( const NotificationMessageV3 &msg )
 {
   if ( msg.type() == NotificationMessageV2::Items ) {
     notifyCollectionStatisticsWatchers( msg.parentCollection(), msg.resource() );
@@ -478,12 +560,17 @@ void MonitorPrivate::slotFlushRecentlyChangedCollections()
   recentlyChangedCollections.clear();
 }
 
-int MonitorPrivate::translateAndCompress( QQueue<NotificationMessageV2> &notificationQueue, const NotificationMessageV2 &msg  )
+int MonitorPrivate::translateAndCompress( QQueue< NotificationMessageV3 >& notificationQueue, const NotificationMessageV3& msg  )
 {
   // We have to split moves into insert or remove if the source or destination
   // is not monitored.
   if ( msg.operation() != NotificationMessageV2::Move ) {
-    return NotificationMessageV2::appendAndCompress( notificationQueue, msg ) ? 1 : 0;
+    return NotificationMessageV3::appendAndCompress( notificationQueue, msg ) ? 1 : 0;
+  }
+
+  // Always handle tags
+  if ( msg.type() == NotificationMessageV2::Tags ) {
+    return NotificationMessageV3::appendAndCompress( notificationQueue, msg );
   }
 
   bool sourceWatched = false;
@@ -508,28 +595,28 @@ int MonitorPrivate::translateAndCompress( QQueue<NotificationMessageV2> &notific
   }
 
   if ( ( sourceWatched && destWatched ) || ( !collectionMoveTranslationEnabled && msg.type() == NotificationMessageV2::Collections ) ) {
-    return NotificationMessageV2::appendAndCompress( notificationQueue, msg ) ? 1 : 0;
+    return NotificationMessageV3::appendAndCompress( notificationQueue, msg ) ? 1 : 0;
   }
 
   if ( sourceWatched )
   {
     // Transform into a removal
-    NotificationMessageV2 removalMessage = msg;
+    NotificationMessageV3 removalMessage = msg;
     removalMessage.setOperation( NotificationMessageV2::Remove );
     removalMessage.setParentDestCollection( -1 );
-    return NotificationMessageV2::appendAndCompress( notificationQueue, removalMessage ) ? 1 : 0;
+    return NotificationMessageV3::appendAndCompress( notificationQueue, removalMessage ) ? 1 : 0;
   }
 
   // Transform into an insertion
-  NotificationMessageV2 insertionMessage = msg;
+  NotificationMessageV3 insertionMessage = msg;
   insertionMessage.setOperation( NotificationMessageV2::Add );
   insertionMessage.setParentCollection( msg.parentDestCollection() );
   insertionMessage.setParentDestCollection( -1 );
   // We don't support batch insertion, so we have to do it one by one
-  const NotificationMessageV2::List split = splitMessage( insertionMessage, false );
+  const NotificationMessageV3::List split = splitMessage( insertionMessage, false );
   int appended = 0;
-  Q_FOREACH (const NotificationMessageV2 &insertion, split ) {
-    if ( NotificationMessageV2::appendAndCompress( notificationQueue, insertion ) ) {
+  Q_FOREACH (const NotificationMessageV3 &insertion, split ) {
+    if ( NotificationMessageV3::appendAndCompress( notificationQueue, insertion ) ) {
       ++appended;
     }
   }
@@ -545,12 +632,12 @@ int MonitorPrivate::translateAndCompress( QQueue<NotificationMessageV2> &notific
   fetchJobDone --> pipeline ?dataAvailable --> emit
  */
 
-void MonitorPrivate::slotNotify( const NotificationMessageV2::List &msgs )
+void MonitorPrivate::slotNotify( const NotificationMessageV3::List &msgs )
 {
   int appendedMessages = 0;
   int modifiedMessages = 0;
   int erasedMessages = 0;
-  foreach ( const NotificationMessageV2 &msg, msgs ) {
+  Q_FOREACH ( const NotificationMessageV3 &msg, msgs ) {
     invalidateCaches( msg );
     updatePendingStatistics( msg );
     bool needsSplit = true;
@@ -591,7 +678,7 @@ void MonitorPrivate::slotNotify( const NotificationMessageV2::List &msgs )
     // (and thus neither is flagsModified), splitMessage() will convert the
     // notification to regular Modify with "FLAGS" part changed
     if ( needsSplit || ( !needsSplit && !supportsBatch && msg.operation() == Akonadi::NotificationMessageV2::ModifyFlags ) ) {
-      const NotificationMessageV2::List split = splitMessage( msg, !supportsBatch );
+      const NotificationMessageV3::List split = splitMessage( msg, !supportsBatch );
       pendingNotifications << split.toList();
       appendedMessages += split.count();
     }
@@ -611,7 +698,7 @@ void MonitorPrivate::slotNotify( const NotificationMessageV2::List &msgs )
 void MonitorPrivate::flushPipeline()
 {
   while ( !pipeline.isEmpty() ) {
-    const NotificationMessageV2 msg = pipeline.head();
+    const NotificationMessageV3 msg = pipeline.head();
     if ( ensureDataAvailable( msg ) ) {
       // dequeue should be before emit, otherwise stuff might happen (like dataAvailable
       // being called again) and we end up dequeuing an empty pipeline
@@ -633,7 +720,7 @@ void MonitorPrivate::dispatchNotifications()
 {
   // Note that this code is not used in a ChangeRecorder (pipelineSize==0)
   while ( pipeline.size() < pipelineSize() && !pendingNotifications.isEmpty() ) {
-    const NotificationMessageV2 msg = pendingNotifications.dequeue();
+    const NotificationMessageV3 msg = pendingNotifications.dequeue();
     if ( ensureDataAvailable( msg ) && pipeline.isEmpty() ) {
       emitNotification( msg );
     } else {
@@ -642,8 +729,7 @@ void MonitorPrivate::dispatchNotifications()
   }
 }
 
-bool MonitorPrivate::emitItemsNotification( const NotificationMessageV2 &msg, const Item::List &items,
-                                            const Collection &collection, const Collection &collectionDest  )
+bool MonitorPrivate::emitItemsNotification( const NotificationMessageV3 &msg, const Item::List& items, const Collection& collection, const Collection& collectionDest  )
 {
   Q_ASSERT( msg.type() == NotificationMessageV2::Items );
   Collection col = collection;
@@ -659,6 +745,12 @@ bool MonitorPrivate::emitItemsNotification( const NotificationMessageV2 &msg, co
       colDest.setResource( QString::fromLatin1( *(msg.itemParts().begin()) ) );
   }
 
+  Tag::List addedTags, removedTags;
+  if ( msg.operation() == NotificationMessageV2::ModifyTags ) {
+    addedTags = tagCache->retrieve( msg.addedTags().toList() );
+    removedTags = tagCache->retrieve( msg.removedTags().toList() );
+  }
+
   QMap<NotificationMessageV2::Id,NotificationMessageV2::Entity> msgEntities = msg.entities();
   Item::List its = items;
   QMutableListIterator<Item> iter( its );
@@ -782,6 +874,12 @@ bool MonitorPrivate::emitItemsNotification( const NotificationMessageV2 &msg, co
         handled = true;
       }
       return handled;
+    case NotificationMessageV2::ModifyTags:
+      if ( q_ptr->receivers( SIGNAL(itemsTagsChanged(Akonadi::Item::List,QSet<Akonadi::Tag>,QSet<Akonadi::Tag>)) ) > 0 ) {
+        emit q_ptr->itemsTagsChanged( its, addedTags.toSet(), removedTags.toSet() );
+        return true;
+      }
+      return false;
     default:
       kDebug() << "Unknown operation type" << msg.operation() << "in item change notification";
   }
@@ -789,8 +887,7 @@ bool MonitorPrivate::emitItemsNotification( const NotificationMessageV2 &msg, co
   return false;
 }
 
-bool MonitorPrivate::emitCollectionNotification( const NotificationMessageV2 &msg, const Collection &col,
-                                                 const Collection &par, const Collection &dest )
+bool MonitorPrivate::emitCollectionNotification( const NotificationMessageV3 &msg, const Collection& col, const Collection& par, const Collection& dest )
 {
   Q_ASSERT( msg.type() == NotificationMessageV2::Collections );
   Collection parent = par;
@@ -857,7 +954,51 @@ bool MonitorPrivate::emitCollectionNotification( const NotificationMessageV2 &ms
   return false;
 }
 
-void MonitorPrivate::invalidateCaches( const NotificationMessageV2& msg )
+bool MonitorPrivate::emitTagsNotification( const NotificationMessageV3 &msg, const Tag::List& tags )
+{
+  Q_ASSERT( msg.type() == NotificationMessageV2::Tags );
+
+  Tag::List validTags;
+  if ( msg.operation() == NotificationMessageV2::Remove ) {
+    //In case of a removed signal the cache entry was already invalidated, and we therefore received an empty list of tags
+    Q_FOREACH ( const Entity::Id &uid, msg.uids() ) {
+      validTags << Tag( uid );
+    }
+  } else {
+    validTags = tags;
+  }
+
+  switch ( msg.operation() ) {
+    case NotificationMessageV2::Add:
+      if ( q_ptr->receivers( SIGNAL(tagAdded(Akonadi::Tag)) ) == 0 )
+        return false;
+      Q_FOREACH ( const Tag &tag, validTags ) {
+        Q_EMIT q_ptr->tagAdded( tag );
+      }
+      return true;
+    case NotificationMessageV2::Modify:
+      if ( q_ptr->receivers( SIGNAL(tagChanged(Akonadi::Tag)) ) == 0 )
+        return false;
+      Q_FOREACH ( const Tag &tag, validTags ) {
+        Q_EMIT q_ptr->tagChanged( tag );
+      }
+      return true;
+    case NotificationMessageV2::Remove:
+      if ( q_ptr->receivers( SIGNAL(tagRemoved(Akonadi::Tag)) ) == 0 )
+        return false;
+      Q_FOREACH ( const Tag &tag, validTags ) {
+        Q_EMIT q_ptr->tagRemoved( tag );
+      }
+      return true;
+    default:
+      kDebug() << "Unknown operation type" << msg.operation() << "in tag change notification";
+  }
+
+  return false;
+}
+
+
+void MonitorPrivate::invalidateCaches( const NotificationMessageV3 &msg )
 {
   // remove invalidates
   if ( msg.operation() == NotificationMessageV2::Remove ) {
@@ -866,6 +1007,8 @@ void MonitorPrivate::invalidateCaches( const NotificationMessageV2& msg )
         collectionCache->invalidate( uid );
     } else if ( msg.type() == NotificationMessageV2::Items ) {
       itemCache->invalidate( msg.uids() );
+    } else if ( msg.type() == NotificationMessageV2::Tags ) {
+      tagCache->invalidate( msg.uids() );
     }
   }
 
@@ -873,6 +1016,7 @@ void MonitorPrivate::invalidateCaches( const NotificationMessageV2& msg )
   // And subscription modify the visibility of the collection by the collectionFetchScope.
   if ( msg.operation() == NotificationMessageV2::Modify
         || msg.operation() == NotificationMessageV2::ModifyFlags
+        || msg.operation() == NotificationMessageV3::ModifyTags
         || msg.operation() == NotificationMessageV2::Move
         || msg.operation() == NotificationMessageV2::Subscribe ) {
     if ( msg.type() == NotificationMessageV2::Collections ) {
@@ -880,6 +1024,8 @@ void MonitorPrivate::invalidateCaches( const NotificationMessageV2& msg )
         collectionCache->update( uid, mCollectionFetchScope );
     } else if ( msg.type() == NotificationMessageV2::Items ) {
       itemCache->update( msg.uids(), mItemFetchScope );
+    } else if ( msg.type() == NotificationMessageV2::Tags ) {
+      tagCache->update( msg.uids(), mTagFetchScope );
     }
   }
 }
