@@ -25,6 +25,7 @@
 #include "job_p.h"
 #include "servermanager.h"
 #include "servermanager_p.h"
+#include "protocolhelper_p.h"
 #include "xdgbasedirs_p.h"
 
 #include <kdebug.h>
@@ -41,6 +42,7 @@
 #include <QtNetwork/QLocalSocket>
 #include <QtNetwork/QTcpSocket>
 #include <QtNetwork/QHostAddress>
+#include <QApplication>
 
 // ### FIXME pipelining got broken by switching result emission in JobPrivate::handleResponse to delayed emission
 // in order to work around exec() deadlocks. As a result of that Session knows to late about a finished job and still
@@ -52,6 +54,12 @@ using namespace Akonadi;
 
 //@cond PRIVATE
 
+static const QList<QByteArray> sCapabilities = QList<QByteArray>()
+        << "NOTIFY 3"
+        << "NOPAYLOADPATH"
+        << "AKAPPENDSTREAMING"
+        << "SERVERSEARCH";
+
 void SessionPrivate::startNext()
 {
   QTimer::singleShot( 0, mParent, SLOT(doStartNext()) );
@@ -122,9 +130,6 @@ void SessionPrivate::reconnect()
     serverAddress = connectionSettings.value( QLatin1String( "Data/UnixPath" ), QString(defaultSocketDir + QLatin1String( "/akonadiserver.socket" )) ).toString();
 #endif
   }
-#ifdef Q_OS_WINCE
-  useTcp = true;
-#endif
 
   // create sockets if not yet done, note that this does not yet allow changing socket types on the fly
   // but that's probably not something we need to support anyway
@@ -142,15 +147,11 @@ void SessionPrivate::reconnect()
 
   // actually do connect
   kDebug() << "connectToServer" << serverAddress;
-#ifdef Q_OS_WINCE
-    tcpSocket->connectToHost( QHostAddress::LocalHost, 31414 );
-#else
   if ( !useTcp ) {
     localSocket->connectToServer( serverAddress );
   } else {
     tcpSocket->connectToHost( serverAddress, port );
   }
-#endif
 
   emit mParent->reconnected();
 }
@@ -191,10 +192,14 @@ void SessionPrivate::dataReceived()
       if ( !parser->parseNextLine( socket->readLine() ) )
         continue; // response not yet completed
 
+      if ( logFile ) {
+        logFile->write( "S: " + parser->data() );
+      }
+
       // handle login response
       if ( parser->tag() == QByteArray( "0" ) ) {
         if ( parser->data().startsWith( "OK" ) ) { //krazy:exclude=strings
-          writeData("1 CAPABILITY (NOTIFY 2 NOPAYLOADPATH)");
+          writeData("1 CAPABILITY (" + ImapParser::join( sCapabilities, " " ) + ")");
         } else {
           kWarning() << "Unable to login to Akonadi server:" << parser->data();
           socket->close();
@@ -336,16 +341,33 @@ int SessionPrivate::nextTag()
 
 void SessionPrivate::writeData(const QByteArray & data)
 {
-  if ( socket )
+  if ( logFile ) {
+    logFile->write( "C: " + data );
+    if ( !data.endsWith( '\n' ) ) {
+      logFile->write( "\n" );
+    }
+    logFile->flush();
+  }
+
+  if ( socket ) {
     socket->write( data );
-  else
+  } else {
     kWarning() << "Trying to write while session is disconnected!" << kBacktrace();
+  }
 }
 
 void SessionPrivate::serverStateChanged( ServerManager::State state )
 {
-  if ( state == ServerManager::Running && !connected )
+  if ( state == ServerManager::Running && !connected ) {
     reconnect();
+  } else if ( !connected && state == ServerManager::Broken ) {
+    // If the server is broken, cancel all pending jobs, otherwise they will be
+    // blocked forever and applications waiting for them to finish would be stuck
+    Q_FOREACH ( Job *job, queue ) {
+      job->setError( Job::ConnectionFailed );
+      job->kill( KJob::EmitResult );
+    }
+  }
 }
 
 void SessionPrivate::itemRevisionChanged( Akonadi::Item::Id itemId, int oldRevision, int newRevision )
@@ -359,7 +381,7 @@ void SessionPrivate::itemRevisionChanged( Akonadi::Item::Id itemId, int oldRevis
 //@endcond
 
 SessionPrivate::SessionPrivate( Session *parent )
-    : mParent( parent ), socket( 0 ), protocolVersion( 0 ), currentJob( 0 ), parser( 0 )
+    : mParent( parent ), socket( 0 ), protocolVersion( 0 ), currentJob( 0 ), parser( 0 ), logFile( 0 )
 {
 }
 
@@ -384,6 +406,19 @@ void SessionPrivate::init( const QByteArray &id )
   mParent->connect( ServerManager::self(), SIGNAL(stateChanged(Akonadi::ServerManager::State)),
                     SLOT(serverStateChanged(Akonadi::ServerManager::State)) );
 
+  const QByteArray sessionLogFile = qgetenv( "AKONADI_SESSION_LOGFILE" );
+  if ( !sessionLogFile.isEmpty() ) {
+    logFile = new QFile( QString::fromLatin1( "%1.%2.%3" ).arg( QString::fromLatin1( sessionLogFile ) )
+                                                          .arg( QString::number( QApplication::applicationPid() ) )
+                                                          .arg( QString::fromLatin1( sessionId ) ),
+                         mParent );
+    if ( !logFile->open( QIODevice::WriteOnly | QIODevice::Truncate ) ) {
+      kWarning() << "Failed to open Akonadi Session log file" << logFile->fileName();
+      delete logFile;
+      logFile = 0;
+    }
+  }
+
   reconnect();
 }
 
