@@ -25,7 +25,7 @@
 class AttributeFactoryTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void initTestCase();
     void testUnknownAttribute();
     void testRegisteredAttribute();
