@@ -36,7 +36,7 @@ using namespace Akonadi;
 class ItemMoveTest: public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void initTestCase()
     {
       AkonadiTest::checkTestIsIsolated();
