@@ -28,9 +28,6 @@
 using namespace Akonadi;
 
 Q_DECLARE_METATYPE( Akonadi::NotificationMessageV2::Operation )
-#ifndef AKONADI_DEFINES_NOTIFICATIONMESSAGEV2TYPEMETATYPE
-Q_DECLARE_METATYPE( Akonadi::NotificationMessageV2::Type )
-#endif
 Q_DECLARE_METATYPE( QSet<QByteArray> )
 
 class MonitorFilterTest : public QObject
@@ -68,7 +65,7 @@ class MonitorFilterTest : public QObject
       Monitor dummyMonitor;
       MonitorPrivate m( 0, &dummyMonitor );
 
-      NotificationMessageV2 msg;
+      NotificationMessageV3 msg;
       msg.addEntity( 1 );
       msg.setOperation( op );
       msg.setType( Akonadi::NotificationMessageV2::Items );
@@ -91,7 +88,7 @@ class MonitorFilterTest : public QObject
       QSignalSpy spy( &dummyMonitor, SIGNAL(itemAdded(Akonadi::Item,Akonadi::Collection)) );
       QVERIFY( spy.isValid() );
 
-      NotificationMessageV2 msg;
+      NotificationMessageV3 msg;
       msg.addEntity( 1 );
       msg.setOperation( NotificationMessageV2::Add );
       msg.setType( Akonadi::NotificationMessageV2::Items );
@@ -137,7 +134,7 @@ class MonitorFilterTest : public QObject
       QSignalSpy spy( &dummyMonitor, signalName );
       QVERIFY( spy.isValid() );
 
-      NotificationMessageV2 msg;
+      NotificationMessageV3 msg;
       msg.addEntity( 1 );
       msg.setOperation( op );
       msg.setParentCollection( 2 );
@@ -178,7 +175,7 @@ class MonitorFilterTest : public QObject
       QSignalSpy spy( &dummyMonitor, signalName );
       QVERIFY( spy.isValid() );
 
-      NotificationMessageV2 msg;
+      NotificationMessageV3 msg;
       msg.setOperation( op );
       msg.setType( type );
       msg.setResource( "foo" );
@@ -235,7 +232,7 @@ class MonitorFilterTest : public QObject
       QSignalSpy spy( &dummyMonitor, signalName );
       QVERIFY( spy.isValid() );
 
-      NotificationMessageV2 msg;
+      NotificationMessageV3 msg;
       msg.addEntity( 1, QString(), QString(), "my/type" );
       msg.setOperation( op );
       msg.setParentCollection( 2 );
@@ -292,7 +289,7 @@ class MonitorFilterTest : public QObject
       QSignalSpy spy( &dummyMonitor, signalName );
       QVERIFY( spy.isValid() );
 
-      NotificationMessageV2 msg;
+      NotificationMessageV3 msg;
       msg.addEntity( 1, QString(), QString(), "my/type" );
       msg.setOperation( op );
       msg.setParentCollection( 2 );
