@@ -30,7 +30,7 @@ using namespace Akonadi;
 class ResourceTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void initTestCase()
     {
       AkonadiTest::checkTestIsIsolated();
@@ -66,8 +66,7 @@ class ResourceTest : public QObject
 
       AgentManager::self()->removeInstance( instance );
       AgentManager::self()->removeInstance( instance2 );
-      QTest::qWait( 2000 );
-      QCOMPARE( spyRemoveInstance.count(), 2 );
+      QTRY_COMPARE( spyRemoveInstance.count(), 2 );
       QVERIFY( !AgentManager::self()->instances().contains( instance ) );
       QVERIFY( !AgentManager::self()->instances().contains( instance2 ) );
     }
