@@ -20,7 +20,7 @@
 
 #include "picturetest.h"
 #include "kabc/picture.h"
-#include <QtGui/QPainter>
+#include <QPainter>
 #include <qtest_kde.h>
 
 QTEST_KDEMAIN( PictureTest, NoGUI )
@@ -38,6 +38,32 @@ static QImage testImage()
   return image;
 }
 
+static QByteArray testImageRawPNG()
+{
+  static QByteArray raw;
+
+  if ( raw.isNull() ) {
+    QBuffer buffer( &raw );
+    buffer.open( QIODevice::WriteOnly );
+    testImage().save( &buffer, "PNG" );
+  }
+
+  return raw;
+}
+
+static QByteArray testImageRawJPEG()
+{
+  static QByteArray raw;
+
+  if ( raw.isNull() ) {
+    QBuffer buffer( &raw );
+    buffer.open( QIODevice::WriteOnly );
+    testImage().save( &buffer, "JPEG" );
+  }
+
+  return raw;
+}
+
 void PictureTest::emptyTest()
 {
   KABC::Picture picture;
@@ -45,15 +71,29 @@ void PictureTest::emptyTest()
   QVERIFY( picture.isEmpty() );
 }
 
-void PictureTest::storeTestIntern()
+void PictureTest::storeTestInternImage()
 {
   KABC::Picture picture;
 
-  picture.setType( QLatin1String( "image/png" ) );
   picture.setData( testImage() );
 
+  QVERIFY( picture.isEmpty() == false );
   QVERIFY( picture.isIntern() == true );
-  QVERIFY( picture.type() == QLatin1String( QLatin1String( "image/png" ) ) );
+  QVERIFY( picture.type() == QLatin1String( "jpeg" ) );
+  QVERIFY( picture.data() == testImage() );
+  QVERIFY( picture.rawData() == testImageRawJPEG() );
+}
+
+void PictureTest::storeTestInternRawData()
+{
+  KABC::Picture picture;
+
+  picture.setRawData( testImageRawPNG(), QLatin1String( "png" ) );
+
+  QVERIFY( picture.isEmpty() == false );
+  QVERIFY( picture.isIntern() == true );
+  QVERIFY( picture.type() == QLatin1String( "png" ) );
+  QVERIFY( picture.rawData() == testImageRawPNG() );
   QVERIFY( picture.data() == testImage() );
 }
 
@@ -61,36 +101,62 @@ void PictureTest::storeTestExtern()
 {
   KABC::Picture picture;
 
-  picture.setType( QLatin1String( "image/png" ) );
-  picture.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ) );
+  picture.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ), QLatin1String( "png" ) );
 
+  QVERIFY( picture.isEmpty() == false );
   QVERIFY( picture.isIntern() == false );
-  QVERIFY( picture.type() == QLatin1String( QLatin1String( "image/png" ) ) );
-  QVERIFY( picture.url() == QLatin1String( QLatin1String( "http://myhomepage.com/foto.png" ) ) );
+  QVERIFY( picture.type() == QLatin1String( "png" ) );
+  QVERIFY( picture.url() == QLatin1String( "http://myhomepage.com/foto.png" ) );
 }
 
-void PictureTest::equalsTestIntern()
+void PictureTest::equalsTestInternImage()
 {
   KABC::Picture picture1, picture2;
 
-  picture1.setType( QLatin1String( "image/png" ) );
   picture1.setData( testImage() );
 
-  picture2.setType( QLatin1String( "image/png" ) );
   picture2.setData( testImage() );
 
   QVERIFY( picture1 == picture2 );
+
+  // access rawData() so a QByteArray is created
+  picture1.rawData();
+  QVERIFY( picture1 == picture2 );
+}
+
+void PictureTest::equalsTestInternRawData()
+{
+  KABC::Picture picture1, picture2;
+
+  picture1.setRawData( testImageRawPNG(), QLatin1String( "png" ) );
+
+  picture2.setRawData( testImageRawPNG(), QLatin1String( "png" ) );
+
+  QVERIFY( picture1 == picture2 );
+
+  // access data() so a QImage is created
+  picture1.data();
+  QVERIFY( picture1 == picture2 );
+}
+
+void PictureTest::equalsTestInternImageAndRawData()
+{
+  KABC::Picture picture1, picture2;
+
+  picture1.setData( testImage() );
+
+  picture2.setRawData( testImageRawJPEG(), QLatin1String( "jpeg" ) );
+
+  QVERIFY( picture1.rawData() == picture2.rawData() );
 }
 
 void PictureTest::equalsTestExtern()
 {
   KABC::Picture picture1, picture2;
 
-  picture1.setType( QLatin1String( "image/png" ) );
-  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ) );
+  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ), QLatin1String( "png" ) );
 
-  picture2.setType( QLatin1String( "image/png" ) );
-  picture2.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ) );
+  picture2.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ), QLatin1String( "png" ) );
 
   QVERIFY( picture1 == picture2 );
 }
@@ -99,20 +165,40 @@ void PictureTest::differsTest()
 {
   KABC::Picture picture1, picture2;
 
-  picture1.setType( QLatin1String( "image/png" ) );
-  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ) );
+  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ), QLatin1String( "png" ) );
 
-  picture2.setType( QLatin1String( "image/png" ) );
   picture2.setData( testImage() );
 
   QVERIFY( picture1 != picture2 );
 }
 
+void PictureTest::differsTestInternRawData()
+{
+  KABC::Picture picture1, picture2;
+
+  picture1.setRawData( testImageRawJPEG(), QLatin1String( "jpeg" ) );
+
+  picture2.setRawData( testImageRawPNG(), QLatin1String( "png" ) );
+
+  QVERIFY( picture1 != picture2 );
+  QVERIFY( picture1.rawData() != picture2.rawData() );
+}
+
+void PictureTest::differsTestExtern()
+{
+  KABC::Picture picture1, picture2;
+
+  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ), QLatin1String( "png" ) );
+
+  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto2.png" ), QLatin1String( "png" ) );
+
+  QVERIFY( picture1 != picture2 );
+}
+
 void PictureTest::assignmentTestIntern()
 {
   KABC::Picture picture1, picture2;
 
-  picture1.setType( QLatin1String( "image/png" ) );
   picture1.setData( testImage() );
 
   picture2 = picture1;
@@ -124,20 +210,17 @@ void PictureTest::assignmentTestExtern()
 {
   KABC::Picture picture1, picture2;
 
-  picture1.setType( QLatin1String( "image/png" ) );
-  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ) );
+  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ), QLatin1String( "png" ) );
 
   picture2 = picture1;
 
   QVERIFY( picture1 == picture2 );
 }
 
-void PictureTest::serializeTest()
+void PictureTest::serializeTestInternImage()
 {
   KABC::Picture picture1, picture2;
 
-  picture1.setType( QLatin1String( "image/png" ) );
-  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ) );
   picture1.setData( testImage() );
 
   QByteArray data;
@@ -150,4 +233,35 @@ void PictureTest::serializeTest()
   QVERIFY( picture1 == picture2 );
 }
 
-#include "picturetest.moc"
+void PictureTest::serializeTestInternRawData()
+{
+  KABC::Picture picture1, picture2;
+
+  picture1.setRawData( testImageRawPNG(), QLatin1String( "png" ) );
+
+  QByteArray data;
+  QDataStream s( &data, QIODevice::WriteOnly );
+  s << picture1;
+
+  QDataStream t( &data, QIODevice::ReadOnly );
+  t >> picture2;
+
+  QVERIFY( picture1 == picture2 );
+}
+
+void PictureTest::serializeTestExtern()
+{
+  KABC::Picture picture1, picture2;
+
+  picture1.setUrl( QLatin1String( "http://myhomepage.com/foto.png" ), QLatin1String( "png" ) );
+
+  QByteArray data;
+  QDataStream s( &data, QIODevice::WriteOnly );
+  s << picture1;
+
+  QDataStream t( &data, QIODevice::ReadOnly );
+  t >> picture2;
+
+  QVERIFY( picture1 == picture2 );
+}
+
