@@ -54,7 +54,7 @@ namespace KCal {
      - birthdays and anniversaries contained in an addressbook
 
 */
-class KCAL_EXPORT CalendarResources
+class KCAL_DEPRECATED_EXPORT CalendarResources
   : public Calendar, public KRES::ManagerObserver<ResourceCalendar>
 {
   Q_OBJECT
@@ -95,8 +95,8 @@ class KCAL_EXPORT CalendarResources
         virtual ResourceCalendar *destination( Incidence *incidence ) = 0;
 
         /**
-	   Return true if we have resources configure. Otherwise returns false.
-           @since 4.3
+          Return true if we have resources configure. Otherwise returns false.
+          @since 4.3
         */
         bool hasCalendarResources();
       protected:
