@@ -31,7 +31,7 @@
 #endif
 
 #include <kglobal.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kdebug.h>
 #include <kcalendarsystem.h>
 
