@@ -34,7 +34,8 @@ namespace KIMAP
     public:
       SelectJobPrivate( Session *session, const QString& name )
         : JobPrivate( session, name ), readOnly( false ), messageCount( -1 ), recentCount( -1 ),
-          firstUnseenIndex( -1 ), uidValidity( -1 ), nextUid( -1 ) { }
+          firstUnseenIndex( -1 ), uidValidity( -1 ), nextUid( -1 ), highestmodseq( 0 ),
+          condstoreEnabled( false ) { }
       ~SelectJobPrivate() { }
 
       QString mailBox;
@@ -47,6 +48,8 @@ namespace KIMAP
       int firstUnseenIndex;
       qint64 uidValidity;
       qint64 nextUid;
+      quint64 highestmodseq;
+      bool condstoreEnabled;
   };
 }
 
@@ -127,6 +130,25 @@ qint64 SelectJob::nextUid() const
   return d->nextUid;
 }
 
+quint64 SelectJob::highestModSequence() const
+{
+  Q_D( const SelectJob );
+  return d->highestmodseq;
+}
+
+void SelectJob::setCondstoreEnabled( bool enable )
+{
+  Q_D( SelectJob );
+  d->condstoreEnabled = enable;
+}
+
+bool SelectJob::condstoreEnabled() const
+{
+  Q_D( const SelectJob );
+  return d->condstoreEnabled;
+}
+
+
 void SelectJob::doStart()
 {
   Q_D( SelectJob );
@@ -136,7 +158,13 @@ void SelectJob::doStart()
     command = "EXAMINE";
   }
 
-  d->tags << d->sessionInternal()->sendCommand( command, '\"'+KIMAP::encodeImapFolderName( d->mailBox.toUtf8() )+'\"' );
+  QByteArray params = '\"'+KIMAP::encodeImapFolderName( d->mailBox.toUtf8() )+'\"';
+
+  if ( d->condstoreEnabled ) {
+    params += " (CONDSTORE)";
+  }
+
+  d->tags << d->sessionInternal()->sendCommand( command, params );
 }
 
 void SelectJob::handleResponse( const Message &response )
@@ -156,25 +184,25 @@ void SelectJob::handleResponse( const Message &response )
 
           if ( code == "PERMANENTFLAGS" ) {
             d->permanentFlags = response.responseCode[1].toList();
+          } else if ( code == "HIGHESTMODSEQ" ) {
+            bool isInt;
+            quint64 value = response.responseCode[1].toString().toULongLong( &isInt );
+            if ( !isInt ) {
+              return;
+            }
+            d->highestmodseq = value;
           } else {
             bool isInt;
-
+            qint64 value = response.responseCode[1].toString().toLongLong( &isInt );
+            if ( !isInt ) {
+              return;
+            }
             if ( code == "UIDVALIDITY" ) {
-              qint64 value = response.responseCode[1].toString().toLongLong( &isInt );
-              if ( !isInt ) {
-                return;
-              }
               d->uidValidity = value;
-            } else {
-              qint64 value = response.responseCode[1].toString().toLongLong( &isInt );
-              if ( !isInt ) {
-                return;
-              }
-              if ( code == "UNSEEN" ) {
-                d->firstUnseenIndex = value;
-              } else if ( code == "UIDNEXT" ) {
-                d->nextUid = value;
-              }
+            } else if ( code == "UNSEEN" ) {
+              d->firstUnseenIndex = value;
+            } else if ( code == "UIDNEXT" ) {
+              d->nextUid = value;
             }
           }
         } else if ( code == "FLAGS" ) {
