@@ -21,7 +21,6 @@
 #include "ldapconfigwidget.h"
 #include "ldapsearch.h"
 
-#include <kacceleratormanager.h>
 #include <kprogressdialog.h>
 #include <kcombobox.h>
 #include <kdebug.h>
@@ -144,7 +143,7 @@ void LdapConfigWidget::Private::initWidget()
     label = new QLabel( i18n( "Host:" ), mParent );
     mHost = new KLineEdit( mParent );
     mHost->setObjectName( QLatin1String("kcfg_ldaphost") );
-
+    mParent->connect(mHost, SIGNAL(textChanged(QString)), SIGNAL(hostNameChanged(QString)));
     mainLayout->addWidget( label, row, 0 );
     mainLayout->addWidget( mHost, row, 1, 1, 3 );
     row++;
