@@ -43,7 +43,7 @@ bool LdapDN::LdapDNPrivate::isValidRDNString( const QString &rdn ) const
   kDebug() << "Testing rdn:" << rdn;
 
   // If it is a muli-valued rdn, split it into its constituent parts
-  const QStringList rdnParts = splitOnNonEscapedChar( rdn, QChar( '+' ) );
+  const QStringList rdnParts = splitOnNonEscapedChar( rdn, QLatin1Char( '+' ) );
   const int rdnPartsSize( rdnParts.size() );
   if ( rdnPartsSize > 1 ) {
     for ( int i = 0; i < rdnPartsSize; i++ ) {
@@ -55,7 +55,7 @@ bool LdapDN::LdapDNPrivate::isValidRDNString( const QString &rdn ) const
   }
 
   // Split the rdn into the attribute name and value parts
-  QStringList components = rdn.split( '=' );
+  QStringList components = rdn.split( QLatin1Char('=') );
 
   // We should have exactly two parts
   if ( components.size() != 2 ) {
@@ -74,7 +74,7 @@ QStringList LdapDN::LdapDNPrivate::splitOnNonEscapedChar( const QString &str,
   int strPartStartIndex = 0;
   while ( ( index = str.indexOf( ch, searchFrom ) ) != -1 ) {
     const QChar prev = str[std::max( 0, index - 1 )];
-    if ( prev != QChar( '\\' ) ) {
+    if ( prev != QLatin1Char( '\\' ) ) {
       // Found a component of a multi-valued RDN
       //kDebug() << "Found" << ch << "at index" << index;
       QString tmp = str.mid( strPartStartIndex, index - strPartStartIndex );
@@ -144,7 +144,7 @@ QString LdapDN::toString() const
 
 QString LdapDN::toString( int depth ) const
 {
-  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QChar( ',' ) );
+  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QLatin1Char( ',' ) );
   if ( depth >= rdns.size() ) {
     return QString();
   }
@@ -152,7 +152,7 @@ QString LdapDN::toString( int depth ) const
   // Construct a DN down to the requested depth
   QString dn;
   for ( int i = depth; i >= 0; i-- ) {
-    dn += rdns.at( rdns.size() - 1 - i ) + QString( "," );
+      dn += rdns.at( rdns.size() - 1 - i ) + QLatin1Char( ',' );
     kDebug() << "dn =" << dn;
   }
   dn = dn.left( dn.length() - 1 ); // Strip off the extraneous comma
@@ -163,13 +163,13 @@ QString LdapDN::toString( int depth ) const
 QString LdapDN::rdnString() const
 {
   /** \TODO We should move this into the d pointer as we calculate rdns quite a lot */
-  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QChar( ',' ) );
+  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QLatin1Char( ',' ) );
   return rdns.at( 0 );
 }
 
 QString LdapDN::rdnString( int depth ) const
 {
-  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QChar( ',' ) );
+  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QLatin1Char( ',' ) );
   if ( depth >= rdns.size() ) {
     return QString();
   }
@@ -181,7 +181,7 @@ bool LdapDN::isValid() const
   kDebug() << "Testing dn:" << d->m_dn;
 
   // Break the string into rdn's
-  const QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QChar( ',' ) );
+  const QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QLatin1Char( ',' ) );
 
   // Test to see if each rdn is valid
   const int rdnsSize( rdns.size() );
@@ -196,7 +196,7 @@ bool LdapDN::isValid() const
 
 int LdapDN::depth() const
 {
-  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QChar( ',' ) );
+  QStringList rdns = d->splitOnNonEscapedChar( d->m_dn, QLatin1Char( ',' ) );
   return rdns.size();
 }
 
