@@ -21,11 +21,12 @@
 
 #include <KDebug>
 #include <KUrl>
+#include <QLocale>
 
 using namespace KMBox;
 
 MBoxPrivate::MBoxPrivate( MBox *mbox )
-  : mInitialMboxFileSize( 0 ), mMBox( mbox ),
+  : mInitialMboxFileSize( 0 ), mMBox( mbox ), mReadOnly( false ),
     mSeparatorMatcher( QLatin1String( "^From .*[0-9][0-9]:[0-9][0-9]" ) )
 {
   connect( &mUnlockTimer, SIGNAL(timeout()), SLOT(unlockMBox()) );
@@ -102,12 +103,15 @@ QByteArray MBoxPrivate::mboxMessageSeparator( const QByteArray &msg )
     separator += from->addresses().first() + ' ';
   }
 
+  // format dateTime according to the mbox "standard" RFC4155
   KMime::Headers::Date *date = mail.date( false );
+  QDateTime dateTime;
   if ( !date || date->isEmpty() ) {
-    separator += QDateTime::currentDateTime().toString( Qt::TextDate ).toUtf8() + '\n';
+    dateTime = QDateTime::currentDateTimeUtc();
   } else {
-    separator += date->as7BitString( false ) + '\n';
+    dateTime = date->dateTime().toUtc().dateTime();
   }
+  separator += QLocale::c().toString(dateTime, QLatin1String("ddd MMM dd HH:mm:ss yyyy")).toUtf8() + '\n';
 
   return separator;
 }
