@@ -37,7 +37,6 @@
 #include <KDE/KMessageBox>
 #include <KDE/KPushButton>
 #include <KDE/KUrl>
-#include <KDE/KImageIO>
 #include <KDE/KIcon>
 
 #include <QtCore/QBuffer>
@@ -49,7 +48,6 @@
 #include <QTextLayout>
 
 #include "textutils.h"
-#include <QPlainTextEdit>
 
 namespace KPIMTextEdit {
 
