@@ -26,8 +26,6 @@
 
 #include <kio/job.h>
 #include <kdebug.h>
-#include <klocalizedstring.h>
-#include <kurl.h>
 
 #include <QtCore/QVariant>
 
