@@ -1,20 +1,20 @@
 /*
-    Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+  This library is free software; you can redistribute it and/or modify it
+  under the terms of the GNU Library General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or (at your
+  option) any later version.
 
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
+  This library is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+  License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #include "messagequeuejob.h"
@@ -73,15 +73,15 @@ class MailTransport::MessageQueueJob::Private
 
 bool MessageQueueJob::Private::validate()
 {
-  if( !message ) {
+  if ( !message ) {
     q->setError( UserDefinedError );
     q->setErrorText( i18n( "Empty message." ) );
     q->emitResult();
     return false;
   }
 
-  if( addressAttribute.to().count() + addressAttribute.cc().count() +
-      addressAttribute.bcc().count() == 0 ) {
+  if ( addressAttribute.to().count() + addressAttribute.cc().count() +
+       addressAttribute.bcc().count() == 0 ) {
     q->setError( UserDefinedError );
     q->setErrorText( i18n( "Message has no recipients." ) );
     q->emitResult();
@@ -89,21 +89,21 @@ bool MessageQueueJob::Private::validate()
   }
 
   const int transport = transportAttribute.transportId();
-  if( TransportManager::self()->transportById( transport, false ) == 0 ) {
+  if ( TransportManager::self()->transportById( transport, false ) == 0 ) {
     q->setError( UserDefinedError );
     q->setErrorText( i18n( "Message has invalid transport." ) );
     q->emitResult();
     return false;
   }
 
-  if( sentBehaviourAttribute.sentBehaviour() == SentBehaviourAttribute::MoveToCollection &&
-      !( sentBehaviourAttribute.moveToCollection().isValid() ) ) {
+  if ( sentBehaviourAttribute.sentBehaviour() == SentBehaviourAttribute::MoveToCollection &&
+       !( sentBehaviourAttribute.moveToCollection().isValid() ) ) {
     q->setError( UserDefinedError );
     q->setErrorText( i18n( "Message has invalid sent-mail folder." ) );
     q->emitResult();
     return false;
-  } else if( sentBehaviourAttribute.sentBehaviour() ==
-             SentBehaviourAttribute::MoveToDefaultSentCollection ) {
+  } else if ( sentBehaviourAttribute.sentBehaviour() ==
+              SentBehaviourAttribute::MoveToDefaultSentCollection ) {
     // TODO require SpecialMailCollections::SentMail here?
   }
 
@@ -115,14 +115,14 @@ void MessageQueueJob::Private::outboxRequestResult( KJob *job )
   Q_ASSERT( !started );
   started = true;
 
-  if( job->error() ) {
+  if ( job->error() ) {
     kError() << "Failed to get the Outbox folder:" << job->error() << job->errorString();
     q->setError( job->error() );
     q->emitResult();
     return;
   }
 
-  if( !validate() ) {
+  if ( !validate() ) {
     // The error has been set; the result has been emitted.
     return;
   }
@@ -145,16 +145,22 @@ void MessageQueueJob::Private::outboxRequestResult( KJob *job )
   item.addAttribute( sentActionAttribute.clone() );
   item.addAttribute( transportAttribute.clone() );
 
-  // update status flags
-  if ( KMime::isSigned( message.get() ) )
+  // Update status flags
+  if ( KMime::isSigned( message.get() ) ) {
     item.setFlag( Akonadi::MessageFlags::Signed );
-  if ( KMime::isEncrypted( message.get() ) )
-    item.setFlag( Akonadi::MessageFlags::Encrypted );
-  if ( KMime::isInvitation( message.get() ) )
-    item.setFlag( Akonadi::MessageFlags::HasInvitation );
-  if ( KMime::hasAttachment( message.get() ) )
-    item.setFlag( Akonadi::MessageFlags::HasAttachment );
+  }
 
+  if ( KMime::isEncrypted( message.get() ) ) {
+    item.setFlag( Akonadi::MessageFlags::Encrypted );
+  }
+
+  if ( KMime::isInvitation( message.get() ) ) {
+    item.setFlag( Akonadi::MessageFlags::HasInvitation );
+  }
+
+  if ( KMime::hasAttachment( message.get() ) ) {
+    item.setFlag( Akonadi::MessageFlags::HasAttachment );
+  }
 
   // Set flags.
   item.setFlag( Akonadi::MessageFlags::Queued );
@@ -224,9 +230,9 @@ void MessageQueueJob::slotResult( KJob *job )
   // error handling
   KCompositeJob::slotResult( job );
 
-  if( !error() ) {
+  if ( !error() ) {
     emitResult();
   }
 }
 
-#include "messagequeuejob.moc"
+#include "moc_messagequeuejob.cpp"
