@@ -23,6 +23,8 @@
 #include <KCmdLineArgs>
 #include <KDebug>
 #include <KJob>
+#include <KLocalizedString>
+#include <KLocale>
 
 #include <akonadi/collection.h>
 #include <akonadi/control.h>
