@@ -46,9 +46,10 @@
 #include <KDebug>
 #include <KEMailSettings>
 #include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KRandom>
-#include <KUrl>
+#include <KGlobal>
 #include <KWallet/Wallet>
 
 #include <akonadi/agentinstance.h>
@@ -291,7 +292,8 @@ bool TransportManager::configureTransport( Transport *transport, QWidget *parent
     return true; // No way to know here if the user cancelled or not.
   }
 
-  QPointer<TransportConfigDialog> transportConfigDialog = new TransportConfigDialog(transport, parent);
+  QPointer<TransportConfigDialog> transportConfigDialog =
+    new TransportConfigDialog( transport, parent );
   transportConfigDialog->setCaption( i18n( "Configure account" ) );
   bool okClicked = ( transportConfigDialog->exec() == QDialog::Accepted );
   delete transportConfigDialog;
@@ -307,12 +309,12 @@ TransportJob *TransportManager::createTransportJob( int transportId )
   t = t->clone(); // Jobs delete their transports.
   t->updatePasswordState();
   switch ( t->type() ) {
-    case Transport::EnumType::SMTP:
-      return new SmtpJob( t, this );
-    case Transport::EnumType::Sendmail:
-      return new SendmailJob( t, this );
-    case Transport::EnumType::Akonadi:
-      return new ResourceSendJob( t, this );
+  case Transport::EnumType::SMTP:
+    return new SmtpJob( t, this );
+  case Transport::EnumType::Sendmail:
+    return new SendmailJob( t, this );
+  case Transport::EnumType::Akonadi:
+    return new ResourceSendJob( t, this );
   }
   Q_ASSERT( false );
   return 0;
@@ -420,7 +422,8 @@ void TransportManagerPrivate::readConfig()
   QRegExp re( QLatin1String( "^Transport (.+)$" ) );
   QStringList groups = config->groupList().filter( re );
   foreach ( const QString &s, groups ) {
-    re.indexIn( s );
+    if (re.indexIn( s ) == -1)
+        continue;
     Transport *t = 0;
 
     // see if we happen to have that one already
